;;
(require "PY.scm")
(require "tcode.scm")
(require "anthy.scm")
(require "prime.scm")
(require "canna.scm")
(require "tutcode.scm")
(require "skk.scm")
(require "viqr.scm")
(require "hangul.scm")
(require "ipa.scm")
(require "romaja.scm")
(require "pyunihan.scm")
;(require "spellcheck.scm")
